@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from asymmetree.datastructures.Tree import Tree, TreeNode
+from asymmetree.datastructures.PhyloTree import PhyloTree, PhyloTreeNode
+
 from asymmetree.datastructures.LinkedList import LinkedList, LinkedListNode
 from asymmetree.datastructures.DoublyLinkedList import DLList, DLListNode
 
